@@ -28,7 +28,7 @@
 
 #include <clipper/clipper.h>
 
-#include "cif++/Structure.hpp"
+#include <cif++.hpp>
 
 // My apologies, but this code is emitting way too many warnings...
 #if defined(_MSC_VER)
@@ -38,11 +38,9 @@
 namespace pdb_redo
 {
 
-using mmcif::Structure;
-using mmcif::kPI;
-using mmcif::Gd;
+using cif::kPI;
 
-template <typename FTYPE>
+template <typename FTYPE = float>
 class Map
 {
   public:
@@ -50,8 +48,11 @@ class Map
 	typedef typename clipper::Xmap<ftype> Xmap;
 
 	Map();
+	Map(const Map &rhs) = default;
 	~Map();
 
+	Map& operator=(const Map &rhs) = default;
+
 	void calculateStats();
 
 	double rmsDensity() const { return mRMSDensity; }
@@ -73,6 +74,12 @@ class Map
 	clipper::Spacegroup spacegroup() const { return mMap.spacegroup(); }
 	clipper::Cell cell() const { return mMap.cell(); }
 
+	/// \brief Create a masked map blotting out the density for all \a atom_ids in the structure contained in \a db
+	Map masked(const cif::mm::structure &structure, const std::vector<cif::mm::atom> &atom_ids) const;
+
+	/// \brief Return the z-weighted density sum for the atoms \a atom_ids in the structure contained in \a db
+	float z_weighted_density(const cif::mm::structure &structure, const std::vector<cif::mm::atom> &atom_ids) const;
+
   private:
 	Xmap mMap;
 	double mMinDensity, mMaxDensity;
@@ -96,7 +103,7 @@ bool IsMTZFile(const std::string &p);
 
 // --------------------------------------------------------------------
 
-template <typename FTYPE>
+template <typename FTYPE = float>
 class MapMaker
 {
   public:
@@ -131,13 +138,13 @@ class MapMaker
 
 	// following works on both mtz files and structure factor files in CIF format
 	void calculate(const std::filesystem::path &hklin,
-		const Structure &structure,
+		const cif::mm::structure &structure,
 		bool noBulk, AnisoScalingFlag anisoScaling,
 		float samplingRate, bool electronScattering = false,
 		std::initializer_list<std::string> foLabels = {"FP", "SIGFP"},
 		std::initializer_list<std::string> freeLabels = {"FREE"});
 
-	void recalc(const Structure &structure,
+	void recalc(const cif::mm::structure &structure,
 		bool noBulk, AnisoScalingFlag anisoScaling,
 		float samplingRate, bool electronScattering = false);
 
